@@ -189,8 +189,7 @@ void DesktopWidget::settingsModified()
     m_Vodafone->SetCredentials(m_Settings->Username, m_Settings->Password);
     delete m_SettingsWindow;
     m_SettingsWindow = NULL;
-    if (!Update())
-        ShowSavedData();
+    Update();
 }
 
 void DesktopWidget::CreateWidgets()
@@ -273,6 +272,8 @@ void DesktopWidget::CreateWidgets()
 bool DesktopWidget::Update()
 {
     bool result = UpdateData();
+    if (!result)
+        ShowSavedData();
     CreateTimer();
     return result;
 }
@@ -379,7 +380,8 @@ bool DesktopWidget::UpdateData()
         SetWidgetSize();
     }else{
         StopWaitAnimation(m_lblCredito);
-        ShowSavedData();
+        m_Updating = false;
+        return false;
     }
 
     m_Settings->Save();
@@ -409,6 +411,7 @@ void DesktopWidget::netStateChanged(QString, QString type, QString state, QStrin
         if (state == "CONNECTED"){
             Update();
         }else if (state == "DISCONNECTING"){
+            m_Vodafone->AbortRequest();
             if (m_UpdateTimer)
                 m_UpdateTimer->stop();
         }
@@ -452,6 +455,12 @@ void DesktopWidget::ShowSavedData()
     if (m_Settings->ShowPunti && m_Settings->LastSaldoPunti != NULL)
         m_lblPunti->setText(QString("%1").arg(m_Settings->LastSaldoPunti->Punti));
 
+    QLayoutItem *child;
+    while ((child = m_CountersLayout->takeAt(0)) != 0) {
+        delete child->widget();
+        delete child;
+    }
+
     foreach(Counter* c, m_Settings->ShowCounters){
         if (c->Soglie.count() > 0){
             c->WidgetSize = m_Settings->CounterStyle;
